@@ -15,6 +15,7 @@ attachShinyWidgetsDep <- function(tag, widget = NULL, extra_deps = NULL) {
     if (widget == "picker") {
       dependencies <- list(
         dependencies,
+        # htmltools::htmlDependencies(shiny::fluidPage())[[1]],
         html_dependency_picker()
       )
     } else if (widget == "awesome") {
@@ -277,10 +278,10 @@ html_dependency_bsswitch <- function() {
     bslib::bs_dependency_defer(bsswitchDependencyCSS),
     htmlDependency(
       name = "bootstrap-switch-js",
-      version = "3.4",
+      version = "3.3.4",
       package = "shinyWidgets",
       src = c(href = "shinyWidgets/bootstrap-switch", file = "assets/bootstrap-switch"),
-      script = "bootstrap-switch-3.4/bootstrap-switch.min.js"
+      script = "bootstrap-switch-3.3.4/bootstrap-switch.min.js"
     )
   )
 }
@@ -289,10 +290,10 @@ bsswitchDependencyCSS <- function(theme) {
   if (!bslib::is_bs_theme(theme)) {
     return(htmlDependency(
       name = "bootstrap-switch-css",
-      version = "3.4",
+      version = "3.3.4",
       package = "shinyWidgets",
       src = c(href = "shinyWidgets/bootstrap-switch", file = "assets/bootstrap-switch"),
-      script = "bootstrap-switch-3.4/bootstrap-switch.min.js",
+      script = "bootstrap-switch-3.3.4/bootstrap-switch.min.js",
       stylesheet = "bootstrap-switch-3.4/bootstrap-switch.min.css"
     ))
   }
@@ -351,16 +352,29 @@ html_dependency_sweetalert2 <- function(theme = c("sweetalert2",
 
 # Non exported ------------------------------------------------------------
 
-
+html_dependency_picker_bs <- function(theme) {
+  if (identical(bslib::theme_version(theme), "5")) {
+    htmlDependency(
+      name = "bootstrap-select",
+      version = "1.14.0",
+      package = "shinyWidgets",
+      src = c(href = "shinyWidgets/bootstrap-select-1.14.0-beta2", file = "assets/bootstrap-select-1.14.0-beta2"),
+      script = c("js/bootstrap-select.min.js"),
+      stylesheet = c("css/bootstrap-select.min.css")
+    )
+  } else {
+    htmlDependency(
+      name = "bootstrap-select",
+      version = "1.13.8",
+      package = "shinyWidgets",
+      src = c(href = "shinyWidgets/bootstrap-select", file = "assets/bootstrap-select"),
+      script = c("js/bootstrap-select.min.js"),
+      stylesheet = c("css/bootstrap-select.min.css")
+    )
+  }
+}
 html_dependency_picker <- function() {
-  htmlDependency(
-    name = "bootstrap-select",
-    version = "1.13.18",
-    package = "shinyWidgets",
-    src = c(href = "shinyWidgets/bootstrap-select", file = "assets/bootstrap-select"),
-    script = c("js/bootstrap-select.min.js"),
-    stylesheet = c("css/bootstrap-select.min.css")
-  )
+  bslib::bs_dependency_defer(html_dependency_picker_bs)
 }
 
 html_dependency_airdatepicker <- function() {
