@@ -2,51 +2,48 @@
 #' Format Numeric Inputs
 #'
 #' Shiny widgets for as-you-type formatting of currency and numeric values. For
-#' a more modifiable version see \code{\link{autonumericInput}}. These two
+#' a more modifiable version see [autonumericInput()]. These two
 #' functions do the exact same thing but are named differently for more
 #' intuitive use (currency for money, formatNumeric for percentage or other).
 #'
 #' @rdname formatNumericInput
 #'
-#' @param inputId The \code{input} slot that will be used to access the value.
+#' @param inputId The `input` slot that will be used to access the value.
 #' @param label Display label for the control, or NULL for no label.
 #' @param value Initial value (unformatted).
 #' @param format A character string specifying the currency format of the
 #'   input.  See "Details" for possible values.
-#' @param width The width of the input box, eg. \code{"200px"} or
+#' @param width The width of the input box, eg. `"200px"` or
 #'   \code{"100\%"}.
 #' @param align The alignment of the text inside the input box, one of
 #'   "center", "left", "right". Defaults to "center".
 #'
 #' @details
-#' In regards to \code{format}, there are currently 41 sets of predefined
+#' In regards to `format`, there are currently 41 sets of predefined
 #' options that can be used, most of which are variations of one another.
 #' The most common are:
 #'
-#' \itemize{
-#'   \item \code{"French"}
-#'   \item \code{"Spanish"}
-#'   \item \code{"NorthAmerican"}
-#'   \item \code{"British"}
-#'   \item \code{"Swiss"}
-#'   \item \code{"Japanese"}
-#'   \item \code{"Chinese"}
-#'   \item \code{"Brazilian"}
-#'   \item \code{"Turkish"}
-#'   \item \code{"euro"} (same as \code{"French"})
-#'   \item \code{"dollar"} (same as \code{"NorthAmerican"})
-#'   \item \code{"percentageEU2dec"}
-#'   \item \code{"percentageUS2dec"}
-#'   \item \code{"dotDecimalCharCommaSeparator"}
-#'   \item \code{"commaDecimalCharDotSeparator"}
-#' }
+#' * "French"
+#' * "Spanish"
+#' * "NorthAmerican"
+#' * "British"
+#' * "Swiss"
+#' * "Japanese"
+#' * "Chinese"
+#' * "Brazilian"
+#' * "Turkish"
+#' * "euro" (same as "French")
+#' * "dollar" (same as "NorthAmerican")
+#' * "percentageEU2dec"
+#' * "percentageUS2dec"
+#' * "dotDecimalCharCommaSeparator"
+#' * "commaDecimalCharDotSeparator"
 #'
 #' To see the full list please visit
-#' \href{https://github.com/autoNumeric/autoNumeric/#predefined-common-options}{this section}
+#' [this section](https://github.com/autoNumeric/autoNumeric/#predefined-common-options)
 #' of the AutoNumeric Github Page.
 #'
-#' @references Bonneau, Alexandre. 2018. "AutoNumeric.js javascript Package".
-#'   \url{http://autonumeric.org}
+#' @references Bonneau, Alexandre. 2018. "AutoNumeric.js javascript Package". http://autonumeric.org
 #'
 #' @return a currency input widget that can be added to the UI of a shiny app.
 #' @export
@@ -133,7 +130,7 @@ formatNumericInput <- function(inputId,
 
 #' Update a Formatted Numeric Input Widget
 #'
-#' @param session Standard shiny \code{session}.
+#' @param session Standard shiny `session`.
 #' @param inputId The id of the input object.
 #' @param label The label to set for the input object.
 #' @param value The value to set for the input object.
@@ -193,7 +190,8 @@ formatNumericInput <- function(inputId,
 #'
 #'   shinyApp(ui, server)
 #' }
-updateCurrencyInput <- function(session, inputId,
+updateCurrencyInput <- function(session = getDefaultReactiveDomain(),
+                                inputId,
                                 label = NULL,
                                 value = NULL,
                                 format = NULL) {
@@ -202,7 +200,8 @@ updateCurrencyInput <- function(session, inputId,
 }
 
 #' @rdname formaNumericInputUpdate
-updateFormatNumericInput <- function(session, inputId,
+updateFormatNumericInput <- function(session = getDefaultReactiveDomain(),
+                                     inputId,
                                      label = NULL,
                                      value = NULL,
                                      format = NULL) {
@@ -212,13 +211,13 @@ updateFormatNumericInput <- function(session, inputId,
 
 #' Autonumeric Input Widget
 #'
-#' An \code{R} wrapper over the javascript \code{AutoNumeric} library, for
+#' An R wrapper over the javascript AutoNumeric library, for
 #' formatting numeric inputs in shiny applications.
 #'
-#' @param inputId The \code{input} slot that will be used to access the value.
+#' @param inputId The `input` slot that will be used to access the value.
 #' @param label Display label for the control, or NULL for no label.
 #' @param value Initial value (unformatted).
-#' @param width The width of the input box, eg. \code{"200px"} or
+#' @param width The width of the input box, eg. `"200px"` or
 #'   \code{"100\%"}.
 #' @param align The alignment of the text inside the input box, one of
 #'   "center" (default), "left", "right".
@@ -239,14 +238,14 @@ updateFormatNumericInput <- function(session, inputId,
 #' @param divisorWhenUnfocused The number that divides the element value on
 #'   blur.  On focus, the number is multiplied back in. Defaults to NULL.
 #' @param rawValueDivisor Divides the formatted value shown in the AutoNumeric
-#'   element and store the divided result in \code{rawValue}. Defaults to 1.
+#'   element and store the divided result in `rawValue`. Defaults to 1.
 #' @param formatOnPageLoad Determine if the default value will be formatted on
 #'   initialization. Defaults to TRUE.
 #' @param maximumValue Defines the maximum possible value a user can enter.
 #' @param minimumValue Defines the minimum possible value a user can enter.
 #' @param modifyValueOnWheel Allows the user to increment or decrement the
 #'   element value with the mouse wheel. The wheel behavior can be modified
-#'   by the \code{wheelStep} option. Defaults to TRUE.
+#'   by the `wheelStep` option. Defaults to TRUE.
 #' @param emptyInputBehavior Defines what should be displayed in the element if the raw value is an empty string ''.
 #' @param ... Additional parameters that can be passed to AutoNumeric.  See
 #'   details for more information.
@@ -255,134 +254,132 @@ updateFormatNumericInput <- function(session, inputId,
 #' This function wraps the AutoNumeric.js library.  The parameter documentation
 #' provided here should be sufficient for most users, but for those wishing to
 #' use advanced configurations it is advised to look at the documentation on
-#' the \href{https://github.com/autoNumeric/autoNumeric}{AutoNumeric GitHub repository}.  Alexandre
+#' the [AutoNumeric GitHub repository](https://github.com/autoNumeric/autoNumeric). Alexandre
 #' Bonneau has done a wonderful job of documenting all parameters and full
 #' explanations of all parameters and their associated values can be found
 #' there.
 #'
-#' The \code{...} parameter can take any of the arguments listed on the
-#' \href{https://github.com/autoNumeric/autoNumeric}{AutoNumeric GitHub repository}. A quick reference
+#' The `...` parameter can take any of the arguments listed on the
+#' [AutoNumeric GitHub repository](https://github.com/autoNumeric/autoNumeric). A quick reference
 #' follows:
 #'
-#' \itemize{
-#'   \item decimalPlacesRawValue - Defines How many decimal places should be kept
-#'   for the raw value. If set to NULL (default) then \code{decimalPlaces} is
+#'  * decimalPlacesRawValue - Defines How many decimal places should be kept
+#'   for the raw value. If set to NULL (default) then `decimalPlaces` is
 #'   used.
-#'   \item decimalPlacesShownOnBlur - Defines how many decimal places should be
+#'   * decimalPlacesShownOnBlur - Defines how many decimal places should be
 #'   visible when the element is unfocused. If NULL (default) then
-#'   \code{decimalPlaces} is used.
-#'   \item decimalPlacesShownOnFocus - Defines how many decimal places should be
+#'   `decimalPlaces` is used.
+#'   * decimalPlacesShownOnFocus - Defines how many decimal places should be
 #'   visible when the element has the focus. If NULL (default) then
-#'   \code{decimalPlaces} is used.
-#'   \item digitalGroupSpacing - Defines how many numbers should be grouped
+#'   `decimalPlaces` is used.
+#'   * digitalGroupSpacing - Defines how many numbers should be grouped
 #'   together for the thousands separator groupings.  Must be one of
 #'   c("2", "2s", "3", "4"). Defaults to 3.
-#'  \item alwaysAllowDecimalCharacter - Defines if the decimal character or
+#'  * alwaysAllowDecimalCharacter - Defines if the decimal character or
 #'   decimal character alternative should be accepted when there is already
 #'   a decimal character shown in the element. If set to TRUE, any decimal
 #'   character input will be accepted and will subsequently modify the decimal
 #'   character position, as well as the rawValue. If set to FALSE, the decimal
 #'   character and its alternative key will be dropped. This is the default
 #'   setting.
-#'   \item createLocalList - Defines if a local list of AutoNumeric objects should
+#'   * createLocalList - Defines if a local list of AutoNumeric objects should
 #'   be kept when initializing this object. Defaults to TRUE.
-#'   \item decimalCharacterAlternative - Allow to declare an alternative decimal
-#'   separator which is automatically replaced by \code{decimalCharacter} when
+#'   * decimalCharacterAlternative - Allow to declare an alternative decimal
+#'   separator which is automatically replaced by `decimalCharacter` when
 #'   typed. This is useful for countries that use a comma ',' as the decimal
 #'   character and have keyboards with numeric pads providing a period '.' as
 #'   the decimal character (in France or Spain for instance). Must be NULL
 #'   (default), ",", or ".".
-#'   \item emptyInputBehavior - Defines what should be displayed in the element if
+#'   * emptyInputBehavior - Defines what should be displayed in the element if
 #'   the raw value is missing. One of c(NULL, "focus", "press", "always", "min",
 #'   "max", "zero") or a custom value. Defaults to NULL.  See
-#'   \href{https://github.com/autoNumeric/autoNumeric}{AutoNumeric GitHub repository} for full
+#'   [AutoNumeric GitHub repository](https://github.com/autoNumeric/autoNumeric) for full
 #'   details.
-#'   \item selectNumberOnly - Determine if the select all keyboard command will
+#'   * selectNumberOnly - Determine if the select all keyboard command will
 #'   select the complete input text, or only the input numeric value.
-#'   Defaults to TRUE.
-#'   \item selectOnFocus - Defines if the element value should be selected on
-#'   focus. Note: The selection is done using the \code{selectNumberOnly} option.
-#'   Defaults to TRUE.
-#'   \item eventBubbles - Defines if the custom and native events triggered by
+#'   Defaults to `TRUE`.
+#'   * selectOnFocus - Defines if the element value should be selected on
+#'   focus. Note: The selection is done using the `selectNumberOnly` option.
+#'   Defaults to `TRUE`.
+#'   * eventBubbles - Defines if the custom and native events triggered by
 #'   AutoNumeric should bubble up or not. Defaults to TRUE.
-#'   \item eventIsCancelable - Defines if the custom and native events triggered
+#'   * eventIsCancelable - Defines if the custom and native events triggered
 #'   by AutoNumeric should be cancelable. Defaults to TRUE.
-#'   \item formulaMode - Defines if the formula mode can be activated by the user.
+#'   * formulaMode - Defines if the formula mode can be activated by the user.
 #'   If set to true, then the user can enter the formula mode by entering the '='
 #'   character. The user will then be allowed to enter any simple math formula
 #'   using numeric characters as well as the following operators: +, -, *, /, (
 #'   and ). The formula mode is exited when the user either validate their math
 #'   expression using the Enter key, or when the element is blurred. Defaults to
-#'   FALSE.
-#'   \item historySize - Set the undo/redo history table size. Defaults to 20.
-#'   \item isCancellable - Allow the user to cancel and undo the changes he made
-#'   to the given autonumeric-managed element, by pressing the \code{Escape}
-#'   key. Defaults to TRUE.
-#'   \item leadingZero - This options describes if entering 0 on the far left of
+#'   `FALSE`.
+#'   * historySize - Set the undo/redo history table size. Defaults to 20.
+#'   * isCancellable - Allow the user to cancel and undo the changes he made
+#'   to the given autonumeric-managed element, by pressing the `Escape`
+#'   key. Defaults to `TRUE`.
+#'   * leadingZero - This options describes if entering 0 on the far left of
 #'   the numbers is allowed, and if the superfluous zeroes should be kept when
 #'   the input is blurred. One of c("allow", "deny", and "keep"). Defaults to
-#'   "deny". See \href{https://github.com/autoNumeric/autoNumeric}{AutoNumeric GitHub repository}
+#'   "deny". See [AutoNumeric GitHub repository](https://github.com/autoNumeric/autoNumeric)
 #'   for full details.
-#'   \item wheelOn - Defines when the wheel event will increment or decrement
+#'   * wheelOn - Defines when the wheel event will increment or decrement
 #'   the element value. One of c("focus", "hover"). Defaults to "focus".
-#'   \item wheelStep - Defines by how much the element value should be
+#'   * wheelStep - Defines by how much the element value should be
 #'   incremented/decremented on the wheel event. Can be a set value or the
 #'   string "progressive" which determines the step from the size of the input.
 #'   Defaults to "progressive".
-#'   \item negativeBracketsTypeOnBlur - Adds brackets-like characters on negative
+#'   * negativeBracketsTypeOnBlur - Adds brackets-like characters on negative
 #'   values when unfocused. Those brackets are visible only when the field does
 #'   not have the focus. The left and right symbols should be enclosed in
 #'   quotes and separated by a comma. Defaults to NULL.
-#'   \item negativePositiveSignPlacement - Placement of the negative/positive sign
-#'   relative to the \code{currencySymbol} option. One of c("p", "s", "l",
+#'   * negativePositiveSignPlacement - Placement of the negative/positive sign
+#'   relative to the `currencySymbol` option. One of c("p", "s", "l",
 #'   "r", NULL), defaults to NULL. See
-#'   \href{https://github.com/autoNumeric/autoNumeric}{AutoNumeric GitHub repository} for further
+#'   [AutoNumeric GitHub repository](https://github.com/autoNumeric/autoNumeric) for further
 #'   documentation.
-#'   \item negativeSignCharacter - Defines the negative sign symbol to use. Must
+#'   * negativeSignCharacter - Defines the negative sign symbol to use. Must
 #'   be a single character and be non-numeric. Defaults to "-".
-#'   \item positiveSignCharacter - Defines the positive sign symbol to use. Must
+#'   * positiveSignCharacter - Defines the positive sign symbol to use. Must
 #'   be a single character and be non-numeric. Defaults to "+".
-#'   \item showPositiveSign - Allow the positive sign symbol
-#'   \code{positiveSignCharacter} to be displayed for positive numbers.
-#'   Defaults to FALSE.
-#'   \item onInvalidPaste - Manage how autoNumeric react when the user tries to
+#'   * showPositiveSign - Allow the positive sign symbol
+#'   `positiveSignCharacter` to be displayed for positive numbers.
+#'   Defaults to `FALSE`.
+#'   * onInvalidPaste - Manage how autoNumeric react when the user tries to
 #'   paste an invalid number. One of c("error", "ignore", "clamp",
 #'   "truncate", "replace"). Defaults to "error".
-#'   \item overrideMinMaxLimits - Override the minimum and maximum limits. Must
+#'   * overrideMinMaxLimits - Override the minimum and maximum limits. Must
 #'   be one of c("ceiling", "floor", "ignore", NULL). Defaults to "ceiling".
-#'   \item readOnly - Defines if the element (<input> or another allowed html tag)
-#'   should be set as read only on initialization. Defaults to FALSE.
-#'   \item roundingMethod - Defines the rounding method to use. One of c("S", "A",
+#'   * readOnly - Defines if the element (`<input>` or another allowed html tag)
+#'   should be set as read only on initialization. Defaults to `FALSE`.
+#'   * roundingMethod - Defines the rounding method to use. One of c("S", "A",
 #'   "s", "a", "B", "U", "D", "C", "F", "N05", "CHF", "U05", "D05"). Defaults
-#'   to "S".  See \href{https://github.com/autoNumeric/autoNumeric}{AutoNumeric GitHub repository}
+#'   to "S".  See [AutoNumeric GitHub repository](https://github.com/autoNumeric/autoNumeric)
 #'   for further documentation.
-#'   \item saveValueToSessionStorage - Set to TRUE to allow the
-#'   \code{decimalPlacesShownOnFocus} value to be saved with sessionStorage.
-#'   Defaults to FALSE.
-#'   \item serializeSpaces - Defines how the serialize functions should treat the
+#'   * saveValueToSessionStorage - Set to TRUE to allow the
+#'   `decimalPlacesShownOnFocus` value to be saved with sessionStorage.
+#'   Defaults to `FALSE`.
+#'   * serializeSpaces - Defines how the serialize functions should treat the
 #'   spaces.  Either "+" (default) or "\%20" (the older behavior).
-#'   \item showOnlyNumbersOnFocus - Defines if the element value should be
+#'   * showOnlyNumbersOnFocus - Defines if the element value should be
 #'   converted to the raw value on focus or mouseenter, (and back to the
-#'   formatted on blur or mouseleave). Defaults to FALSE.
-#'   \item showWarnings - Defines if warnings should be shown in the console.
-#'   Defaults to TRUE.
-#'   \item styleRules - Defines the rules that calculate the CSS class(es) to
+#'   formatted on blur or mouseleave). Defaults to `FALSE`.
+#'   * showWarnings - Defines if warnings should be shown in the console.
+#'   Defaults to `TRUE`.
+#'   * styleRules - Defines the rules that calculate the CSS class(es) to
 #'   apply on the element, based on the raw unformatted value. Defaults to
 #'   NULL.
-#'   \item suffixText - Add a text on the right hand side of the element value.
+#'   * suffixText - Add a text on the right hand side of the element value.
 #'   This suffix text can have any characters in its string, except numeric
-#'   characters and the negative or positive sign. Defaults to NULL.
-#'   \item symbolWhenUnfocused - Defines the symbol placed as a suffix when not
-#'   in focus or hovered. Defaults to NULL.
-#'   \item unformatOnHover - Defines if the element value should be unformatted
+#'   characters and the negative or positive sign. Defaults to `NULL`.
+#'   * symbolWhenUnfocused - Defines the symbol placed as a suffix when not
+#'   in focus or hovered. Defaults to `NULL`.
+#'   * unformatOnHover - Defines if the element value should be unformatted
 #'   when the user hover his mouse over it while holding the Alt key. Defaults
-#'   to TRUE.
-#'   \item valuesToStrings - Provides a way for automatically replacing the
+#'   to `TRUE`.
+#'   * valuesToStrings - Provides a way for automatically replacing the
 #'   formatted value with a pre-defined string, when the raw value is equal
 #'   to a specific value. Defaults to NULL.
-#'   \item watchExternalChanges - Defines if the AutoNumeric element should watch
-#'   external changes made without using \code{.set()}. Defaults to FALSE.
-#' }
+#'   * watchExternalChanges - Defines if the AutoNumeric element should watch
+#'   external changes made without using `.set()`. Defaults to `FALSE`.
 #'
 #' @return An autonumericInput object to be used in the UI function of a Shiny
 #'   App.
@@ -392,8 +389,7 @@ updateFormatNumericInput <- function(session, inputId,
 #'
 #' @family autonumeric
 #'
-#' @references Bonneau, Alexandre. 2018. "AutoNumeric.js javascript Package".
-#'   \url{http://autonumeric.org}
+#' @references Bonneau, Alexandre. 2018. "AutoNumeric.js javascript Package". http://autonumeric.org
 #'
 #' @examples
 #' if (interactive()) {
@@ -603,7 +599,8 @@ autonumericInput <- function(inputId, label, value,
 #'
 #'   shinyApp(ui, server)
 #' }
-updateAutonumericInput <- function(session, inputId,
+updateAutonumericInput <- function(session = getDefaultReactiveDomain(),
+                                   inputId,
                                    label = NULL,
                                    value = NULL,
                                    options = NULL) {
